import { HttpStatus } from '@nestjs/common';
export declare enum SortDirection {
    asc = 1,
    desc = -1
}
export declare class RESTSort {
    property: string;
    direction: SortDirection;
}
export interface IMongoPage {
    skip: number;
    limit: number;
}
export declare class RESTPaging {
    page: number;
    size: number;
    extract(): {
        skip: number;
        limit: number;
    };
    static generate(page: number, size: number): IMongoPage;
}
export declare abstract class RESTRequestBody {
    abstract data: any;
    paging: RESTPaging;
    sort: RESTSort[];
    isPagingPresent(): boolean;
    isSortPresent(): boolean;
    extractPaging(): {
        skip: number;
        limit: number;
    };
    extractSort(): {};
}
export declare class RESTPage {
    page: number;
    size: number;
    number: number;
    total: number;
    static create(count: number, paging: RESTPaging): RESTPage;
}
export declare class RESTResult<T> {
    data: T;
    page: RESTPage;
    sort: RESTSort[];
}
export declare class RESTError {
    keyword: string;
    debug?: any;
    validation?: any;
    statusCode?: HttpStatus;
    constructor(keyword: string, debug?: any, statusCode?: HttpStatus);
    static dataValidation(validation: any): RESTError;
    static createFromCatch(e: any, fallback: {
        keyword: string;
        debug?: any;
        statusCode?: HttpStatus;
    }): RESTError;
}
export declare class RESTResponseBody<T> {
    statusCode: number;
    result: RESTResult<T>;
    errors: RESTError[];
    addError(error: RESTError): void;
    static success<T>(data: T, page?: RESTPage, sort?: RESTSort[]): RESTResponseBody<T>;
    static fail(errors: RESTError[], statusCode?: number): RESTResponseBody<any>;
}
export declare class RESTQueryParams extends RESTPaging {
    sort: string[];
    getRESTSort(): RESTSort[];
    extractSort(): {};
}
