import { HydratedDocument, mongo } from 'mongoose';
import { IFileEmbedded, IFileLog, IFileMeta, IFileRecord, IFileState, ILogInitiator, IS3, IS3File } from '../../interfaces/s3.interface';
import { FileLogInitType, S3FileState } from '../../enums/s3.enum';
export declare class S3 implements IS3 {
    key: string;
    bucket: string;
    etag: string;
}
export declare class LogInitiator implements ILogInitiator {
    type: FileLogInitType;
    name: string;
}
export declare class FileLog implements IFileLog {
    createdAt: Date;
    value: S3FileState;
    initiator: LogInitiator;
}
export declare class FileMeta implements IFileMeta {
    name: string;
    size: number;
    mimeType: string;
    extension: string;
}
export declare class FileState implements IFileState {
    value: S3FileState;
    log: FileLog[];
}
export declare class FileRecord implements IFileRecord {
    createdAt: Date;
    updatedAt: Date;
}
export declare class S3File implements IS3File {
    id: mongo.ObjectId;
    fileMeta: FileMeta;
    state: FileState;
    s3: S3;
    record: FileRecord;
    owner: string;
}
export declare class FileEmbedded implements IFileEmbedded {
    id: string;
    name: string;
    size: number;
    mimeType: string;
    s3: S3;
    state: S3FileState;
    createdAt: Date;
}
export declare const S3Schema: import("mongoose").Schema<S3, import("mongoose").Model<S3, any, any, any, import("mongoose").Document<unknown, any, S3> & S3 & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, S3, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<S3>> & import("mongoose").FlatRecord<S3> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const LogInitiatorSchema: import("mongoose").Schema<LogInitiator, import("mongoose").Model<LogInitiator, any, any, any, import("mongoose").Document<unknown, any, LogInitiator> & LogInitiator & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, LogInitiator, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<LogInitiator>> & import("mongoose").FlatRecord<LogInitiator> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const FileLogSchema: import("mongoose").Schema<FileLog, import("mongoose").Model<FileLog, any, any, any, import("mongoose").Document<unknown, any, FileLog> & FileLog & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, FileLog, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<FileLog>> & import("mongoose").FlatRecord<FileLog> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const FileMetaSchema: import("mongoose").Schema<FileMeta, import("mongoose").Model<FileMeta, any, any, any, import("mongoose").Document<unknown, any, FileMeta> & FileMeta & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, FileMeta, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<FileMeta>> & import("mongoose").FlatRecord<FileMeta> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const FileStateSchema: import("mongoose").Schema<FileState, import("mongoose").Model<FileState, any, any, any, import("mongoose").Document<unknown, any, FileState> & FileState & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, FileState, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<FileState>> & import("mongoose").FlatRecord<FileState> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const FileRecordSchema: import("mongoose").Schema<FileRecord, import("mongoose").Model<FileRecord, any, any, any, import("mongoose").Document<unknown, any, FileRecord> & FileRecord & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, FileRecord, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<FileRecord>> & import("mongoose").FlatRecord<FileRecord> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const S3FileSchema: import("mongoose").Schema<S3File, import("mongoose").Model<S3File, any, any, any, import("mongoose").Document<unknown, any, S3File> & S3File & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, S3File, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<S3File>> & import("mongoose").FlatRecord<S3File> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export declare const FileEmbeddedSchema: import("mongoose").Schema<FileEmbedded, import("mongoose").Model<FileEmbedded, any, any, any, import("mongoose").Document<unknown, any, FileEmbedded> & FileEmbedded & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}, any>, {}, {}, {}, {}, import("mongoose").DefaultSchemaOptions, FileEmbedded, import("mongoose").Document<unknown, {}, import("mongoose").FlatRecord<FileEmbedded>> & import("mongoose").FlatRecord<FileEmbedded> & {
    _id: import("mongoose").Types.ObjectId;
} & {
    __v: number;
}>;
export type S3Document = HydratedDocument<S3>;
export type LogInitiatorDocument = HydratedDocument<LogInitiator>;
export type FileLogDocument = HydratedDocument<FileLog>;
export type FileMetaDocument = HydratedDocument<FileMeta>;
export type FileStateDocument = HydratedDocument<FileState>;
export type FileRecordDocument = HydratedDocument<FileRecord>;
export type S3FileDocument = HydratedDocument<S3File>;
export type FileEmbeddedDocument = HydratedDocument<FileEmbedded>;
